@@ -282,7 +282,7 @@ class DataDumper(object):
         self.session.commit()
 
     async def dump_custom_role_members(self, dbtype):
-        parents = self.session.query(RoleDefinition).filter(RoleDefinition.isBuiltIn == False)
+        parents = self.session.query(RoleDefinition).all()
         cache = []
         for parent in parents:
             url = 'https://graph.windows.net/%s/roleAssignments?api-version=%s&$filter=roleDefinitionId eq \'%s\'' % (self.tenantid, self.api_version, parent.objectId)
@@ -302,7 +302,7 @@ async def run(args, dburl):
     elif args.tenant:
         tenantid = args.tenant
     else:
-        tenantid = 'myorganisation'
+        tenantid = 'myorganization'
     expiretime = time.mktime(time.strptime(token['expiresOn'].split('.')[0], '%Y-%m-%d %H:%M:%S'))
     headers = {
         'Authorization': '%s %s' % (token['tokenType'], token['accessToken'])
@@ -341,6 +341,7 @@ async def run(args, dburl):
         'Microsoft.DirectoryServices.Group': (Group, 'memberGroups'),
         'Microsoft.DirectoryServices.Contact': (Contact, 'memberContacts'),
         'Microsoft.DirectoryServices.Device': (Device, 'memberDevices'),
+        'Microsoft.DirectoryServices.ServicePrincipal': (ServicePrincipal, 'memberServicePrincipals'),
     }
     owner_mapping = {
         'Microsoft.DirectoryServices.User': (User, 'ownerUsers'),
@@ -387,6 +388,10 @@ def getargs(gather_parser):
     gather_parser.add_argument('--mfa',
                                action='store_true',
                                help='Dump MFA details (requires use of a privileged account)')
+    gather_parser.add_argument('-t',
+                               '--tenant',
+                               action='store',
+                               help='Tenant ID to gather, if this info is not stored in the token')
 
 def main(args=None):
     global token, headers, dburl, urlcounter
@@ -413,7 +418,11 @@ def main(args=None):
     headers['Authorization'] = '%s %s' % (token['tokenType'], token['accessToken'])
 
     seconds = time.perf_counter()
-    asyncio.run(run(args, dburl))
+    try:
+        asyncio.run(run(args, dburl))
+    except AttributeError:
+        loop = asyncio.get_event_loop()
+        loop.run_until_complete(run(args, dburl))
     elapsed = time.perf_counter() - seconds
     print("ROADrecon gather executed in {0:0.2f} seconds and issued {1} HTTP requests.".format(elapsed, urlcounter))
 
