@@ -27,7 +27,7 @@ class RTModelConverter(ModelConverter):
     )
 
 # Our custom model schema which uses the model converter from above
-class RTModelSchema(ma.SQLAlchemySchema):
+class RTModelSchema(ma.SQLAlchemyAutoSchema):
     class Meta:
         model_converter = RTModelConverter
 
@@ -67,7 +67,7 @@ class SimpleServicePrincipalsSchema(ma.Schema):
 class ServicePrincipalsSchema(ma.Schema):
     class Meta:
         model = ServicePrincipal
-        fields = ('objectId', 'objectType', 'displayName', 'appDisplayName', 'appId', 'appOwnerTenantId', 'publisherName', 'replyUrls', 'appRoles', 'microsoftFirstParty', 'isDirSyncEnabled', 'oauth2Permissions', 'passwordCredentials', 'keyCredentials', 'ownerUsers', 'ownerServicePrincipals', 'accountEnabled')
+        fields = ('objectId', 'objectType', 'displayName', 'appDisplayName', 'appId', 'appOwnerTenantId', 'publisherName', 'replyUrls', 'appRoles', 'microsoftFirstParty', 'isDirSyncEnabled', 'oauth2Permissions', 'passwordCredentials', 'keyCredentials', 'ownerUsers', 'ownerServicePrincipals', 'accountEnabled', 'servicePrincipalType')
     ownerUsers = fields.Nested(UsersSchema, many=True)
     ownerServicePrincipals = fields.Nested(SimpleServicePrincipalsSchema, many=True)
 
@@ -104,6 +104,7 @@ class GroupSchema(RTModelSchema):
         model = Group
     memberOf = fields.Nested(GroupsSchema, many=True)
     memberUsers = fields.Nested(UsersSchema, many=True)
+    memberServicePrincipals = fields.Nested(SimpleServicePrincipalsSchema, many=True)
 
 class ServicePrincipalSchema(RTModelSchema):
     class Meta(RTModelSchema.Meta):
@@ -111,6 +112,7 @@ class ServicePrincipalSchema(RTModelSchema):
     ownerUsers = fields.Nested(UsersSchema, many=True)
     ownerServicePrincipals = fields.Nested(ServicePrincipalsSchema, many=True)
     memberOfRole = fields.Nested(DirectoryRoleSchema, many=True)
+    memberOf = fields.Nested(GroupSchema, many=True)
 
 
 class ApplicationSchema(RTModelSchema):
@@ -336,6 +338,15 @@ def get_stats():
     }
     return jsonify(stats)
 
+def create_app_test():
+    '''
+    Create app for unit tests
+    '''
+    global db
+    app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:///' + os.path.join(os.getcwd(), 'roadrecon.db')
+    db = SQLAlchemy(app)
+    return app
+
 def main(args=None):
     global db
     if not args:
